#!/usr/bin/env python

# This file is part of librefdatool. librefdatool is free software: you can
# redistribute it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Copyright (C) 2013 Javier D. Garcia-Lasheras
#


from distutils.core import setup
from distutils.command.install_data import install_data
from distutils.dep_util import newer
from distutils.log import info
import glob
import os
import sys

__version__ = '0.1'

class InstallData(install_data):
  def run (self):
    install_data.run (self)

setup(
    name='librefdatool',
    version=__version__,
    namespace_packages=['librefdatool'],
    include_package_data=True,
    maintainer='Javier D. Garcia-Lasheras',
    maintainer_email='javier@garcialasheras.com',
    license='LGPLv3',
    url='http:www.owhr.org/projects/libre-fdatool',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: '
            'GNU Lesser General Public License v3 or later (LGPLv3+)',
        'Operating System :: POSIX',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: MacOS :: MacOS X',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        ],
      scripts=['librefdatool'],
      data_files=[
                  ('share/applications', ['data/librefdatool.desktop']),
                  ('share/man/man1', ['man/librefdatool.1']),
                  ('share/doc/librefdatool', ['doc/README', 'doc/changelog']),
                  ('share/librefdatool/data/images', glob.glob('data/images/*')),
                  ('share/librefdatool/data/icons', glob.glob('data/icons/*')),
                  ('share/librefdatool/src', glob.glob('src/*.py')),
                 ],
      cmdclass={'install_data': InstallData}
    )
